==> skill-core-1.12.3-sources.jar: com/ptteng/skill/service/service/UserTaskRelationService.java <==
package com.ptteng.skill.service.service;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;
import com.ptteng.skill.service.model.UserTaskRelation;
import org.osoa.sca.annotations.Remotable;

import java.util.List;

@Remotable
public interface UserTaskRelationService extends BaseDaoService {

	



   		   
		
		public Long insert(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTaskRelation> insertList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public UserTaskRelation getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTaskRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserTaskRelationIdsByUidAndOid(Long uid, Long oid)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Long  getUserTaskRelationIdByTidAndUid(Long tid, Long uid)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserTaskRelationIdsByUidAndOid(Long uid, Long oid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserTaskRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countUserTaskRelationIds() throws ServiceException, ServiceDaoException;
	

}

==> skill-core-12.0.0-sources.jar: com/ptteng/skill/service/service/UserTaskRelationService.java <==
package com.ptteng.skill.service.service;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.common.dao.BaseDaoService;
import com.ptteng.skill.service.model.UserTaskRelation;
import org.osoa.sca.annotations.Remotable;

import java.util.List;

@Remotable
public interface UserTaskRelationService extends BaseDaoService {

	



   		   
		
		public Long insert(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTaskRelation> insertList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean delete(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean update(UserTaskRelation userTaskRelation)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public boolean updateList(List<UserTaskRelation> userTaskRelationList)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public UserTaskRelation getObjectById(Long id)throws ServiceException, ServiceDaoException;
		  
    	   
		
		public List<UserTaskRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException;
		  
    	
	


			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer  countUserTaskRelationIdsByUidAndOid(Long uid, Long oid)throws ServiceException, ServiceDaoException;
					
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Long  getUserTaskRelationIdByTidAndUid(Long tid, Long uid)throws ServiceException, ServiceDaoException;
			
			
	/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long>  getUserTaskRelationIdsByUidAndOid(Long uid, Long oid, Integer start, Integer limit)throws ServiceException, ServiceDaoException;
		
	
	
	
	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserTaskRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException;

	/**
	 * 
	 * @param
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public Integer countUserTaskRelationIds() throws ServiceException, ServiceDaoException;


	/**
	 *
	 * @param uid
	 * @return
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	public List<Long> getUserTaskRelationIdsByUid(Long uid,Integer start, Integer limit)throws ServiceException,ServiceDaoException;
}
